@@ -46,6 +46,7 @@ p.truth <- function(model,p,par2,group){
          "direct" = pt <- 1 ,
          "Warner" =    pt <- 2*p-1, # ifelse(2*p-1<0, 1-2*p,2*p-1),
          "Crosswise" = pt <- 2*p-1, # ifelse(2*p-1<0, 1-2*p,2*p-1),
+         "Triangular" = pt <- 1-p,
          "Mangat" = pt <- p,
          "Kuk" =  pt <- p[1]-p[2],
          "FR" = pt <- 1-sum(p) ,
@@ -78,6 +79,7 @@ y.mean <- function(model,p,par2,group){
          "direct" = y.mu <- 0 ,
          "Warner" =    y.mu <-  1/2,
          "Crosswise" = y.mu <-  1/2,
+         "Triangular" = y.mu <- 1,
          "Mangat" = y.mu <- 1,
          "Kuk" = y.mu <- p[2]/(1-p[1]+p[2]),
          "FR" = y.mu <- ifelse(all(p==0),0, 1/sum(p)*p %*% 0:(length(p)-1)),
